@@ -25,6 +25,7 @@ from colemen_config import _db_column_type,_db_column_sql_data_type,_db_column_v
 
 import colemen_utilities.type_utils as _type
 import colemen_utilities.dict_utils as _obj
+import colemen_utilities.list_utils as _lu
 import colemen_utilities.database_utils.MySQL.Column.column_utils as _u
 import colemen_utilities.database_utils.MySQL.Relationship.Relationship as _rel
 import colemen_utilities.console_utils as _con
@@ -64,7 +65,7 @@ class Column:
                 sql_data = data['sql_data']
             # @Mstep [] have the data instance populate from the sql_data
             self.data.populate_from_meta(sql_data)
-            
+
             if 'form_data' in data:
                 self.form.populate_from_dict(data['form_data'])
             if 'validation' in data:
@@ -362,8 +363,8 @@ class Column:
                 for ft in self._column.table.raw_fulltext_indexes:
                     if ft['column_name'] == self.column_name:
                         self.is_fulltext_indexed = True
-            
-            
+
+
         @property
         def is_nullable(self)->bool:
             '''
@@ -499,7 +500,7 @@ class Column:
             '''
                 Get this Column's foreign_key_data
                 If this column is a foreign key, this will return a dictionary of the foreign key data:
-                
+
                 - schema_name
                 - table_name
                 - column_name
@@ -525,7 +526,7 @@ class Column:
                 "foreign_table_schema":self.foreign_table_schema,
                 "foreign_table_name":self.foreign_table_name,
                 "foreign_column_name":self.foreign_column_name,
-                "foreign_key_constraint_name":self.foreign_key_constraint_name,                
+                "foreign_key_constraint_name":self.foreign_key_constraint_name,
             }
             return value
 
@@ -666,7 +667,7 @@ class Column:
                 "py_data_type":self._column.data.py_data_type,
                 "required":self.required,
                 "unix_timestamp":self.unix_timestamp,
-                "value_options":self.value_options,
+                "value_options":self._column.form.value_options,
                 "create_validation_schema":self.cerberus_schema("create",True),
                 "read_validation_schema":self.cerberus_schema("read",True),
                 "update_validation_schema":self.cerberus_schema("update",True),
@@ -890,6 +891,12 @@ class Column:
         _column:_db_column_type = None
         data:_db_column_sql_data_type = None
 
+        no_post_args:bool = False
+        '''True if this column should never be allowed as a form body key'''
+
+        no_form:bool = False
+        '''True if this column should not be included in any form.'''
+
         create_form:bool = False
         '''True if this column should be included in create forms'''
         read_form:bool = True
@@ -898,10 +905,10 @@ class Column:
         '''True if this column should be included in update forms'''
         delete_form:bool = False
         '''True if this column should be included in delete forms'''
-        input_type:bool = False
+
+        _input_type:str = None
         '''The type of input used to enter the data.'''
-        no_form:bool = False
-        '''True if this column should not be included in any form.'''
+
         no_create:bool = False
         '''True if this column should not be included in any create form.'''
         no_read:bool = False
@@ -910,12 +917,17 @@ class Column:
         '''True if this column should not be included in any update form.'''
         no_delete:bool = False
         '''True if this column should not be included in any delete form.'''
-        value_options = None
+
+        _value_options = None
         '''A list of values used as options in a radio input.'''
 
         def __init__(self,column:_db_column_type):
             self._column:_db_column_type = column
             self.data:_db_column_sql_data_type = column.data
+            self.create_forms = []
+            self.read_forms = []
+            self.update_forms = []
+            self.delete_forms = []
 
         def summary(self):
             value = {
@@ -930,6 +942,11 @@ class Column:
                 "no_update":self.no_update,
                 "no_delete":self.no_delete,
                 "value_options":self.value_options,
+                "no_post_args":self.no_post_args,
+                "create_forms":self.create_forms,
+                "read_forms":self.read_forms,
+                "update_forms":self.update_forms,
+                "delete_forms":self.delete_forms,
             }
             # output = {}
             # for k,v in value.items():
@@ -940,12 +957,142 @@ class Column:
 
         def populate_from_dict(self,data:dict):
             for k,v in data.items():
+                if k == "create_form":
+                    self.create_form = True
+                    if isinstance(v,(list,str)):
+                        self.add_form('create',v)
+
+                if k == "read_form":
+                    self.read_form = True
+                    if isinstance(v,(list,str)):
+                        self.add_form('read',v)
+
+                if k == "update_form":
+                    self.update_form = True
+                    if isinstance(v,(list,str)):
+                        self.add_form('update',v)
+
+                if k == "delete_form":
+                    self.delete_form = True
+                    if isinstance(v,(list,str)):
+                        self.add_form('delete',v)
+
                 if hasattr(self,k):
                     setattr(self,k,v)
+                else:
+                    _log(f"No column form attribute for {k}:{v}","warning")
+
+        def add_form(self,crud_type:str,form_name):
+            crud_type = crud_type.lower()
+            if crud_type not in ['create','read','update','delete']:
+                return False
+            form_names = _lu.force_list(form_name)
+            for form_name in form_names:
+                if crud_type == 'create':
+                    if form_name not in self.create_forms:
+                        self.create_forms.append(form_name)
+                if crud_type == 'read':
+                    if form_name not in self.read_forms:
+                        self.read_forms.append(form_name)
+                if crud_type == 'update':
+                    if form_name not in self.update_forms:
+                        self.update_forms.append(form_name)
+                if crud_type == 'delete':
+                    if form_name not in self.delete_forms:
+                        self.delete_forms.append(form_name)
+
+        @property
+        def input_type(self):
+            '''
+                The type of input used to enter the data.
+
+                `default`:None
 
 
+                Meta
+                ----------
+                `@author`: Colemen Atwood
+                `@created`: 12-19-2022 11:57:41
+                `@memberOf`: Column
+                `@property`: input_type
+            '''
+            if self._input_type is None or self._input_type is False:
+                if self._column.data.py_data_type in ['string']:
+                    if self._column.data.character_maximum_length < 256:
+                        self._input_type = "single_line_input"
+
+                    if self._column.data.character_maximum_length > 256:
+                        self._input_type = "text_area_input"
+
+                if self._column.data.py_data_type == "integer":
+                    self._input_type = "number_input"
+
+                if self._column.data.py_data_type == "boolean":
+                    self._input_type = "toggle_button"
 
 
+                if self._column.validation.unix_timestamp is True and self._column.data.py_data_type in ['integer']:
+                    self._input_type = "date_input"
+
+                if self._column.data.column_name in ["timestamp","modified_timestamp","start_timestamp","end_timestamp","deleted","birthday","deactivated","established","last_login_timestamp","last_activity_timestamp","email_verified","disabled","is_abandoned","last_abandoned_alert"]:
+                    self._input_type = "date_input"
+
+                if self.value_options is not None:
+                    self._input_type = "select_input"
+
+
+            return self._input_type
+
+        @input_type.setter
+        def input_type(self,value):
+            '''
+                Set the Column's input_type property
+
+                `default`:None
+
+
+                Meta
+                ----------
+                `@author`: Colemen Atwood
+                `@created`: 12-19-2022 12:03:28
+                `@memberOf`: Column
+                `@property`: input_type
+            '''
+            self._input_type = value
+
+
+        @property
+        def value_options(self)->list:
+            '''
+                A list of values used as options in a select input.
+
+                `default`:None
+
+
+                Meta
+                ----------
+                `@author`: Colemen Atwood
+                `@created`: 12-19-2022 12:16:17
+                `@memberOf`: PostArg
+                `@property`: value_options
+            '''
+            return self._value_options
+
+        @value_options.setter
+        def value_options(self,value):
+            '''
+                Set the value_options value.
+
+                Meta
+                ----------
+                `@author`: Colemen Atwood
+                `@created`: 12-19-2022 12:16:17
+                `@memberOf`: PostArg
+                `@property`: value_options
+            '''
+            if isinstance(value,(bool)) is True or value is None:
+                return False
+            self._value_options = value
 
 
 # def _format_cerberus_schema_for_json(schema):
