@@ -1324,11 +1324,21 @@ class MySQLDatabase:
 
 
 
-    # def get_all_relationships(self)->Iterable[_db_relationship_type]:
-    #     table:_db_table_type
-    #     for _,table in self._tables.items():
-    #         for col in table.columns:
-    #             if col.data.is_foreign_key:
+    def get_all_relationships(self)->Iterable[_db_relationship_type]:
+        table:_db_table_type
+        for _,table in self._tables.items():
+            for col in table.columns:
+                if col.data.is_foreign_key:
+                    _log("Column.relationship --- Relationship Found","magenta")
+                    value = Relationship.Relationship(
+                        self,
+                        col.table,
+                        col,
+                        col.data.foreign_key_data
+                    )
+                    self._relationship = value
+                    if self.no_caching is False:
+                        col.table.save_cache()
 
 
 
