@@ -57,6 +57,14 @@ class Table:
     index_length = None
     data_free = None
     auto_increment = None
+    
+    # ----------------------------------- ROLES ---------------------------------- #
+    create_roles = None
+    read_roles = None
+    update_roles = None
+    delete_roles = None
+    
+    
     # create_time = None
     # update_time = None
     # check_time = None
@@ -67,8 +75,10 @@ class Table:
     name_ = None
     _cerberus_validations = None
 
+    # TODO []: get all form names
+    # TODO []: get columns by form name
 
-
+    _hash_id = None
     _primary_id = None
     '''The column instance of this table's primary id.'''
     _Columns = []
@@ -220,6 +230,10 @@ class Table:
             "table_comment":self.table_comment,
             "raw_fulltext_indexes":self.raw_fulltext_indexes,
             "raw_referential_constraints":self.raw_referential_constraints,
+            "create_roles":self.create_roles,
+            "read_roles":self.read_roles,
+            "update_roles":self.update_roles,
+            "delete_roles":self.delete_roles,
             # "create_options":self.create_options,
             # "create_roles":self.create_roles,
             # "read_roles":self.read_roles,
@@ -450,8 +464,29 @@ class Table:
                     value = col
                     self._primary_id = col
                     break
-
         return value
+    
+    @property
+    def hash_id(self):
+        '''
+            Get this Table's hash_id column instance, if it exists.
+
+            `default`:None
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 12-19-2022 11:03:27
+            `@memberOf`: Table
+            `@property`: hash_id
+        '''
+        if self.has_hash_id:
+            for col in self.columns:
+                if col.data.is_hash_id:
+                    self._hash_id = col
+                    return self._hash_id
+        return None
 
 
     @property
